@@ -33,7 +33,7 @@ module Data.Vector.Algorithms.Intro
        ( -- * Sorting
          sort
        , sortBy
-       , sortByBounds 
+       , sortByBounds
          -- * Selecting
        , select
        , selectBy
@@ -62,7 +62,7 @@ import qualified Data.Vector.Algorithms.Heap      as H
 -- | Sorts an entire array using the default ordering.
 sort :: (PrimMonad m, MVector v e, Ord e) => v (PrimState m) e -> m ()
 sort = sortBy compare
-{-# INLINE sort #-}
+{-# INLINABLE sort #-}
 
 -- | Sorts an entire array using a custom ordering.
 sortBy :: (PrimMonad m, MVector v e) => Comparison e -> v (PrimState m) e -> m ()
@@ -156,6 +156,8 @@ partialSortByBounds cmp a k l u
   | l >= u    = return ()
   | otherwise = go (ilg len) l (l + k) u
  where
+ isort = introsort cmp a
+ {-# INLINE [1] isort #-}
  len = u - l
  go 0 l m n = H.partialSortByBounds cmp a (m - l) l u
  go n l m u
@@ -165,9 +167,9 @@ partialSortByBounds cmp a k l u
                     mid <- partitionBy cmp a p (l+1) u
                     unsafeSwap a l (mid - 1)
                     case compare m mid of
-                      GT -> do introsort cmp a (n-1) l (mid - 1)
+                      GT -> do isort (n-1) l (mid - 1)
                                go (n-1) mid m u
-                      EQ -> introsort cmp a (n-1) l m
+                      EQ -> isort (n-1) l m
                       LT -> go n l m (mid - 1)
   where c = (u + l) `div` 2
 {-# INLINE partialSortByBounds #-}
